@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2017 Guido Flohr <guido.flohr@cantanea.com>, 
+# Copyright (C) 2016-2019 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This file is distributed under the same terms and conditions as
@@ -9,7 +9,7 @@
 
 package File::Globstar::ListMatch;
 
-use strict;
+use common::sense;
 
 use File::Temp;
 use Git;
